pub struct IrMetadata {
pub source_hash: String,
pub compiled_at: u64,
pub compiler_version: String,
pub parameters: Vec<ParamDecl>,
pub data_sources: Vec<DataDecl>,
}Expand description
Metadata for IR provenance
Fields
source_hash: Stringcompiled_at: u64compiler_version: Stringparameters: Vec<ParamDecl>data_sources: Vec<DataDecl>Trait Implementations
Sourceimpl Archive for IrMetadata
impl Archive for IrMetadata
Sourcetype Archived = ArchivedIrMetadata
type Archived = ArchivedIrMetadata
The archived representation of this type. Read more
Sourcetype Resolver = IrMetadataResolver
type Resolver = IrMetadataResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for IrMetadata
impl Clone for IrMetadata
Sourcefn clone(&self) -> IrMetadata
fn clone(&self) -> IrMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IrMetadata
impl Debug for IrMetadata
Sourceimpl<__D: Fallible + ?Sized> Deserialize<IrMetadata, __D> for Archived<IrMetadata>
impl<__D: Fallible + ?Sized> Deserialize<IrMetadata, __D> for Archived<IrMetadata>
Sourcefn deserialize(&self, deserializer: &mut __D) -> Result<IrMetadata, __D::Error>
fn deserialize(&self, deserializer: &mut __D) -> Result<IrMetadata, __D::Error>
Deserializes using the given deserializer