pub struct ParamDecl {
pub name: String,
pub default_value: f64,
}Expand description
Parameter declaration
Fields
name: Stringdefault_value: f64Trait Implementations
Sourceimpl Archive for ParamDecl
impl Archive for ParamDecl
Sourcetype Archived = ArchivedParamDecl
type Archived = ArchivedParamDecl
The archived representation of this type. Read more
Sourcetype Resolver = ParamDeclResolver
type Resolver = ParamDeclResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.