pub struct TypeAnnotation {
pub dtype: DType,
pub shape: Shape,
}Expand description
Type annotation combining dtype and shape
Fields
dtype: DTypeshape: ShapeTrait Implementations
Sourceimpl Archive for TypeAnnotation
impl Archive for TypeAnnotation
Sourcetype Archived = ArchivedTypeAnnotation
type Archived = ArchivedTypeAnnotation
The archived representation of this type. Read more
Sourcetype Resolver = TypeAnnotationResolver
type Resolver = TypeAnnotationResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for TypeAnnotation
impl Clone for TypeAnnotation
Sourcefn clone(&self) -> TypeAnnotation
fn clone(&self) -> TypeAnnotation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TypeAnnotation
impl Debug for TypeAnnotation
Sourceimpl<__D: Fallible + ?Sized> Deserialize<TypeAnnotation, __D> for Archived<TypeAnnotation>
impl<__D: Fallible + ?Sized> Deserialize<TypeAnnotation, __D> for Archived<TypeAnnotation>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<TypeAnnotation, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<TypeAnnotation, __D::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for TypeAnnotation
impl PartialEq for TypeAnnotation
impl Eq for TypeAnnotation
impl StructuralPartialEq for TypeAnnotation